/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_FwRqGSxT);
  numBytes += sLine_init(&sLine_S0T6Umkf);
  numBytes += sTabhead_init(&sTabhead_LRDwZy5p, &hTable_nwHTRhln);
  numBytes += sTabread_init(&sTabread_wsUlEnhj, &hTable_nwHTRhln, false);
  numBytes += sTabread_init(&sTabread_zeNKv9yM, &hTable_nwHTRhln, false);
  numBytes += sLine_init(&sLine_L0ZJkojx);
  numBytes += sLine_init(&sLine_wO6E4ILF);
  numBytes += sLine_init(&sLine_IvKBfGhx);
  numBytes += sTabhead_init(&sTabhead_PgXFOL4E, &hTable_RHjd0M2A);
  numBytes += sTabread_init(&sTabread_AutGd6Wx, &hTable_RHjd0M2A, false);
  numBytes += sTabread_init(&sTabread_USL6nXye, &hTable_RHjd0M2A, false);
  numBytes += sLine_init(&sLine_1HcDueMl);
  numBytes += sTabwrite_init(&sTabwrite_XozThD2d, &hTable_nwHTRhln);
  numBytes += sTabwrite_init(&sTabwrite_lB6MzHd5, &hTable_RHjd0M2A);
  numBytes += sRPole_init(&sRPole_fT1lqf9W);
  numBytes += sRPole_init(&sRPole_cEVvvuSt);
  numBytes += sRPole_init(&sRPole_ooxLRzUO);
  numBytes += sDel1_init(&sDel1_MGrl1H7y);
  numBytes += sLine_init(&sLine_vmbl2UT9);
  numBytes += sLine_init(&sLine_OqbZbbFT);
  numBytes += sRPole_init(&sRPole_hhIReGre);
  numBytes += sRPole_init(&sRPole_I41MgiXu);
  numBytes += sRPole_init(&sRPole_maAG4yNd);
  numBytes += sDel1_init(&sDel1_yFm0xmC2);
  numBytes += sLine_init(&sLine_VdA2SG1c);
  numBytes += sLine_init(&sLine_8dJH45m1);
  numBytes += sLine_init(&sLine_STjB5l4b);
  numBytes += sLine_init(&sLine_ya8NliPL);
  numBytes += cVar_init_f(&cVar_WX31vYo6, 0.0f);
  numBytes += cVar_init_f(&cVar_y7P55ijh, 0.0f);
  numBytes += cVar_init_f(&cVar_Zabvi97j, 0.0f);
  numBytes += cVar_init_f(&cVar_1gtpbXDe, 0.0f);
  numBytes += cSlice_init(&cSlice_x8WhEC3k, 1, -1);
  numBytes += cVar_init_f(&cVar_KAF29Qr7, 0.5f);
  numBytes += cSlice_init(&cSlice_m5NnKGeE, 1, -1);
  numBytes += cVar_init_f(&cVar_RrEaoiJY, 0.2f);
  numBytes += cSlice_init(&cSlice_SkIjSHl5, 1, -1);
  numBytes += cVar_init_f(&cVar_OAJODOgc, 500.0f);
  numBytes += cSlice_init(&cSlice_cBvUM7VV, 1, -1);
  numBytes += cVar_init_f(&cVar_2nvT5Kyf, 0.25f);
  numBytes += cDelay_init(this, &cDelay_l5cezxbt, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Hub4JQVd, 0.0f);
  numBytes += hTable_init(&hTable_nwHTRhln, 256);
  numBytes += cDelay_init(this, &cDelay_j1oqibuo, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5TL2hQlg, 0.0f);
  numBytes += hTable_init(&hTable_RHjd0M2A, 256);
  numBytes += cVar_init_f(&cVar_niTCNzyY, 8000.0f);
  numBytes += cBinop_init(&cBinop_YAuUK2pf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JxOH7E3J, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2VclhD00, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZOq8ysey, 8000.0f);
  numBytes += cBinop_init(&cBinop_uj450PIq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RwnmUzOs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P42bGxhh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OGybeCDF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_I4u8wuc7, 300.0f);
  numBytes += cBinop_init(&cBinop_gyiAR3Wr, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_VPlDQFMr, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_7GAr14Gf, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_1OXkZ7vq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zahyPjrI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GMikc1lG, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_7P9qRyOd, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_WRrdGEAP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yJiVPpnz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KsgFhS3w, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TY0bgjHB, 8000.0f);
  numBytes += cBinop_init(&cBinop_MfD87KbT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6s7faMvk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pIIm8xnA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vXMgrwFK, 8000.0f);
  numBytes += cBinop_init(&cBinop_GJjo3J3i, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IrePXWeE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bWEVxBqB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mAmUBUBM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_RmdEMNcW, 300.0f);
  numBytes += cBinop_init(&cBinop_uGDqb4LI, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_9hp6f2wz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8DJ7xIgU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E56eBJNu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IEiPqI8y, 1.0f);
  numBytes += cIf_init(&cIf_mCq29jIK, false);
  numBytes += cIf_init(&cIf_73X9jOcT, false);
  numBytes += cVar_init_f(&cVar_BGo7UYB2, 0.0f);
  numBytes += cVar_init_f(&cVar_md5ryDRJ, 0.0f);
  numBytes += cVar_init_f(&cVar_PcG2a52K, 60000.0f);
  numBytes += cVar_init_f(&cVar_Njs5dThZ, 500.0f);
  numBytes += cSlice_init(&cSlice_xj35LjUX, 1, -1);
  numBytes += cSlice_init(&cSlice_kqDhsaiz, 1, -1);
  numBytes += cVar_init_f(&cVar_mtb29ET8, 0.0f);
  numBytes += cIf_init(&cIf_zPJzssOZ, false);
  numBytes += cBinop_init(&cBinop_KdW71ze5, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_BbLqVxOR, 120.0f);
  numBytes += cBinop_init(&cBinop_sNmyFX8U, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_SA4omiXZ, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_nwHTRhln);
  hTable_free(&hTable_RHjd0M2A);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_nwHTRhln; // del-1011-delayL
    case 0xF057CB49: return &hTable_RHjd0M2A; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JGs9PhHn_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_66WPHcEc_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6rcO3Py6_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gzUjRh0C_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GUxEctux_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MNXyp7AG_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S5Mmlahf_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_58JUBOO3_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TqwdOk2p_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_teR9G24E_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2jlfti2r_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AFRxuXSI_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_WX31vYo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GuNonHi6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_y7P55ijh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZArTCX7s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_Zabvi97j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PoebhOh4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_1gtpbXDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ksw6wvlO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_tCarGOd4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x8WhEC3k, 0, m, &cSlice_x8WhEC3k_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_x8WhEC3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nT6rzNez_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nT6rzNez_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_KAF29Qr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nT6rzNez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_nT6rzNez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TqwdOk2p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_8U3eEoCQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_m5NnKGeE, 0, m, &cSlice_m5NnKGeE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_y863iX0k_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_m5NnKGeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MSfw3YUQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MSfw3YUQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_RrEaoiJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MSfw3YUQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_MSfw3YUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S5Mmlahf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_TbjWeCoy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SkIjSHl5, 0, m, &cSlice_SkIjSHl5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tCarGOd4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_SkIjSHl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P85eNyAK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P85eNyAK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_OAJODOgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P85eNyAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_P85eNyAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_teR9G24E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_XOFMq4p2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QSmgLqZe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QSmgLqZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_pm88IFLW_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_HnupXVCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xAARg9te_sendMessage(_c, 0, m);
  cMsg_JbsjT7Oc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_MKJ6GOgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o1UmTjpn_sendMessage(_c, 0, m);
  cMsg_rf0XRJQe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_pm88IFLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2DE3JjXZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2DE3JjXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dpQS6EgA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wG9mMrVP_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_wG9mMrVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uZ3eIR1R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_dpQS6EgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Z3a2ABF7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z3a2ABF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ok9HP6av_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_uZ3eIR1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5ATpvelG_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5ATpvelG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I3Bb2AFd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ok9HP6av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_HnupXVCr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_I3Bb2AFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_MKJ6GOgD_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_q23LFib1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_34eJrTf5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_34eJrTf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Z4WAvaz2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z4WAvaz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PrwS66mO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PrwS66mO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YoopoVju_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xXyMjoua_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_YoopoVju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RY0Rs3vL_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_xXyMjoua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ysoHjFx3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_RY0Rs3vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zoi1oxpg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ysoHjFx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hFblprgy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_hFblprgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6MxgAuZe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6MxgAuZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7xr0b6TY_sendMessage(_c, 0, m);
  cMsg_chN460kb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_zoi1oxpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cwY3OaXe_sendMessage(_c, 0, m);
  cMsg_XCLADf5L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_y863iX0k_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cBvUM7VV, 0, m, &cSlice_cBvUM7VV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TbjWeCoy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_cBvUM7VV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Lo74DwcA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Lo74DwcA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_2nvT5Kyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lo74DwcA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_Lo74DwcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_58JUBOO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_IhnBioiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z1vMzHp3_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Z1vMzHp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Wmx7maFY_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_l5cezxbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l5cezxbt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hub4JQVd, 0, m, &cDelay_Hub4JQVd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_l5cezxbt, 0, m, &cDelay_l5cezxbt_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XozThD2d, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_Hub4JQVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Hub4JQVd, m);
  cMsg_UwwUbawF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_dcERrpIY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_DPp9IQeb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_n2d3tmh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2hKEsoQ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_nwHTRhln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KVVWitLo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_l5cezxbt, 2, m, &cDelay_l5cezxbt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KEesF7aI_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2hKEsoQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_nwHTRhln, 0, m, &hTable_nwHTRhln_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Wmx7maFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_n2d3tmh1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_UwwUbawF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_nwHTRhln, 0, m, &hTable_nwHTRhln_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_KEesF7aI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l5cezxbt, 0, m, &cDelay_l5cezxbt_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_KVVWitLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hub4JQVd, 2, m, &cDelay_Hub4JQVd_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_DPp9IQeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XozThD2d, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_vY6LaGVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D1oMU9mR_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_D1oMU9mR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bHPDmVqw_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_j1oqibuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j1oqibuo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TL2hQlg, 0, m, &cDelay_5TL2hQlg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1oqibuo, 0, m, &cDelay_j1oqibuo_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lB6MzHd5, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_5TL2hQlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5TL2hQlg, m);
  cMsg_Y0N0GybQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_iZabvrrF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LzcscTBq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_ottVteYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a0bTUCQq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_RHjd0M2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZTIJ5hOC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1oqibuo, 2, m, &cDelay_j1oqibuo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2pTk0FRu_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_a0bTUCQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_RHjd0M2A, 0, m, &hTable_RHjd0M2A_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bHPDmVqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_ottVteYe_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Y0N0GybQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_RHjd0M2A, 0, m, &hTable_RHjd0M2A_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_2pTk0FRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1oqibuo, 0, m, &cDelay_j1oqibuo_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZTIJ5hOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TL2hQlg, 2, m, &cDelay_5TL2hQlg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_LzcscTBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lB6MzHd5, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_niTCNzyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YAuUK2pf, HV_BINOP_MULTIPLY, 0, m, &cBinop_YAuUK2pf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_FuwOPb3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L0PFIeBw_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_L0PFIeBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5yYVIrv5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_YAuUK2pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QFjog0wk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sY7UnFWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YAuUK2pf, HV_BINOP_MULTIPLY, 1, m, &cBinop_YAuUK2pf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5yYVIrv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sY7UnFWr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QFjog0wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vKw7b1H2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vKw7b1H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_APDpSjHB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2VclhD00, m);
}

void Heavy_WSTD_DLAY::cBinop_APDpSjHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JxOH7E3J, m);
}

void Heavy_WSTD_DLAY::cVar_ZOq8ysey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uj450PIq, HV_BINOP_MULTIPLY, 0, m, &cBinop_uj450PIq_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4k0VD03R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iWcsspYH_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_iWcsspYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnKTNmXi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_uj450PIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_s2JumJOz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_RYPXB9Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uj450PIq, HV_BINOP_MULTIPLY, 1, m, &cBinop_uj450PIq_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bnKTNmXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RYPXB9Ny_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_s2JumJOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_X7s9dou6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_X7s9dou6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Hqg4l1jX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_P42bGxhh, m);
}

void Heavy_WSTD_DLAY::cBinop_Hqg4l1jX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RwnmUzOs, m);
}

void Heavy_WSTD_DLAY::cBinop_XFRGtjCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XiCkoyO4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XiCkoyO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5K60Mm8z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kwoQ8NFm_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_I4u8wuc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Qjv10sSk_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bk9qPHq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MvnSb5ol_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_MvnSb5ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gyiAR3Wr, HV_BINOP_DIVIDE, 1, m, &cBinop_gyiAR3Wr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5K60Mm8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_faMnTjap_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_faMnTjap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VPlDQFMr, m);
}

void Heavy_WSTD_DLAY::cMsg_wa8JQ1qU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WQcCSZbe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WQcCSZbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XFRGtjCr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kwoQ8NFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OGybeCDF, m);
}

void Heavy_WSTD_DLAY::cBinop_Qjv10sSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_KzzX8s6l_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KzzX8s6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gyiAR3Wr, HV_BINOP_DIVIDE, 0, m, &cBinop_gyiAR3Wr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gyiAR3Wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wa8JQ1qU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_gQJke5OB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VNaQpTY8_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_VNaQpTY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qZxf9LXZ_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_7GAr14Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9fd6i2tm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_qSLsKRIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eXmGd4ic_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1OXkZ7vq, m);
}

void Heavy_WSTD_DLAY::cBinop_qZxf9LXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zahyPjrI, m);
}

void Heavy_WSTD_DLAY::cMsg_9fd6i2tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qSLsKRIi_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_eXmGd4ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GMikc1lG, m);
}

void Heavy_WSTD_DLAY::cMsg_B1tJ4dUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jwDnYih4_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_jwDnYih4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xL8xy8qk_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_7P9qRyOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0S4dLoec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_3iNAfodq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PKsbleTe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WRrdGEAP, m);
}

void Heavy_WSTD_DLAY::cBinop_xL8xy8qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yJiVPpnz, m);
}

void Heavy_WSTD_DLAY::cMsg_0S4dLoec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3iNAfodq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PKsbleTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KsgFhS3w, m);
}

void Heavy_WSTD_DLAY::cVar_TY0bgjHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfD87KbT, HV_BINOP_MULTIPLY, 0, m, &cBinop_MfD87KbT_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bXvXfyIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rklB4u8b_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_rklB4u8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6I0tX7Us_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_MfD87KbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nvYQxtDM_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nFZgtMr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfD87KbT, HV_BINOP_MULTIPLY, 1, m, &cBinop_MfD87KbT_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6I0tX7Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nFZgtMr5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nvYQxtDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NlNQCOqk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NlNQCOqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PNwvrfg3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pIIm8xnA, m);
}

void Heavy_WSTD_DLAY::cBinop_PNwvrfg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6s7faMvk, m);
}

void Heavy_WSTD_DLAY::cVar_vXMgrwFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GJjo3J3i, HV_BINOP_MULTIPLY, 0, m, &cBinop_GJjo3J3i_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Q90x0BUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KMFIO4Nr_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_KMFIO4Nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4enO9lcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_GJjo3J3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Y8pKNEr1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_p3aRyezp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GJjo3J3i, HV_BINOP_MULTIPLY, 1, m, &cBinop_GJjo3J3i_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4enO9lcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_p3aRyezp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Y8pKNEr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ul5jR7dJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ul5jR7dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_HxEJVZZf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bWEVxBqB, m);
}

void Heavy_WSTD_DLAY::cBinop_HxEJVZZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IrePXWeE, m);
}

void Heavy_WSTD_DLAY::cBinop_rZAl19RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gU1sPE2Y_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gU1sPE2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_K0xt9rTO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_K9yvyUzH_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_RmdEMNcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_QMERh3nB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fWeiCsWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7BcKvt7c_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_7BcKvt7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uGDqb4LI, HV_BINOP_DIVIDE, 1, m, &cBinop_uGDqb4LI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_K0xt9rTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OvqhvC74_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_OvqhvC74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9hp6f2wz, m);
}

void Heavy_WSTD_DLAY::cMsg_o4ZQeZ8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KsKhDgQM_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KsKhDgQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rZAl19RJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_K9yvyUzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mAmUBUBM, m);
}

void Heavy_WSTD_DLAY::cBinop_QMERh3nB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_cdjBoASc_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_cdjBoASc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uGDqb4LI, HV_BINOP_DIVIDE, 0, m, &cBinop_uGDqb4LI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_uGDqb4LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o4ZQeZ8S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_xAARg9te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L0ZJkojx, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_o1UmTjpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FwRqGSxT, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_rf0XRJQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wO6E4ILF, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_JbsjT7Oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1HcDueMl, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_XCLADf5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8dJH45m1, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7xr0b6TY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OqbZbbFT, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_cwY3OaXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ya8NliPL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_chN460kb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_STjB5l4b, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_HPioXMjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S0T6Umkf, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_6BtkA9F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IvKBfGhx, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_wq4w40A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vmbl2UT9, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ekazCZHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VdA2SG1c, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_IEiPqI8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7M883hUx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fPJpH3tM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_o10f8HLU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7M883hUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IEiPqI8y, 1, m, &cVar_IEiPqI8y_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_mCq29jIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_y7P55ijh, 0, m, &cVar_y7P55ijh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_73X9jOcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_y7P55ijh, 0, m, &cVar_y7P55ijh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_BGo7UYB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_73X9jOcT, 0, m, &cIf_73X9jOcT_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_md5ryDRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mCq29jIK, 0, m, &cIf_mCq29jIK_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_PcG2a52K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNmyFX8U, HV_BINOP_DIVIDE, 0, m, &cBinop_sNmyFX8U_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Njs5dThZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SA4omiXZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_SA4omiXZ_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_liAFsYlr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xj35LjUX, 0, m, &cSlice_xj35LjUX_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kqDhsaiz, 0, m, &cSlice_kqDhsaiz_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PDfKe4k7_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V0cJzKH3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_xj35LjUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_mtb29ET8, 0, m, &cVar_mtb29ET8_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_mtb29ET8, 0, m, &cVar_mtb29ET8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_kqDhsaiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_KdW71ze5, HV_BINOP_NEQ, 1, m, &cBinop_KdW71ze5_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_mtb29ET8, 1, m, &cVar_mtb29ET8_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_KdW71ze5, HV_BINOP_NEQ, 1, m, &cBinop_KdW71ze5_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_mtb29ET8, 1, m, &cVar_mtb29ET8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_mtb29ET8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_wDy4PlGa_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_zPJzssOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xFZAKV9K_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NOCfdngP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_NOCfdngP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mtb29ET8, 0, m, &cVar_mtb29ET8_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_xFZAKV9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KdW71ze5, HV_BINOP_NEQ, 1, m, &cBinop_KdW71ze5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KdW71ze5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPJzssOZ, 1, m, &cIf_zPJzssOZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_V0cJzKH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPJzssOZ, 0, m, &cIf_zPJzssOZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_PDfKe4k7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KdW71ze5, HV_BINOP_NEQ, 0, m, &cBinop_KdW71ze5_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_BbLqVxOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tf2IIU9B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PG9pa1W1_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_6obXUsK6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WCMiTE25_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_42P89PWp_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_esQ79qfm_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4L0F0kHy_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ccbUlxib_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BeV6cUvh_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X5eXzrJx_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Q2DkZni_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oTjmBgKl_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h1qjYZfV_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7BrrYLg5_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EY5wqcnH_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1oGxzsxQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_WCMiTE25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EGDAiv7b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_42P89PWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6zLXdOXP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_esQ79qfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lej5JYIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_4L0F0kHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1nDGtkEq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ccbUlxib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eyD5KbLd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_BeV6cUvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72rtkaJo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_X5eXzrJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yNlPObIV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_7Q2DkZni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k9Lq6nz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_oTjmBgKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4kZk34en_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_h1qjYZfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjgZNOMO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_7BrrYLg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6VTNRJDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_EY5wqcnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uytH5GzY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_1oGxzsxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jR3dyh5R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_sNmyFX8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SA4omiXZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_SA4omiXZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_SA4omiXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_liAFsYlr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_PG9pa1W1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PcG2a52K, 0, m, &cVar_PcG2a52K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Njs5dThZ, 0, m, &cVar_Njs5dThZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_tf2IIU9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNmyFX8U, HV_BINOP_DIVIDE, 1, m, &cBinop_sNmyFX8U_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_HryMJQ7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Njs5dThZ, 0, m, &cVar_Njs5dThZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_kcZuPdLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PcG2a52K, 0, m, &cVar_PcG2a52K_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_EGDAiv7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6zLXdOXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Lej5JYIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_1nDGtkEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_eyD5KbLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_72rtkaJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_yNlPObIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_k9Lq6nz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4kZk34en_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SjgZNOMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6VTNRJDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_uytH5GzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_jR3dyh5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HryMJQ7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kcZuPdLE_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Ksw6wvlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8U3eEoCQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_GuNonHi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8U3eEoCQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_MaFwKMiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1gtpbXDe, 0, m, &cVar_1gtpbXDe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7nPDrt3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WX31vYo6, 0, m, &cVar_WX31vYo6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nPno2M9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zabvi97j, 0, m, &cVar_Zabvi97j_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZArTCX7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8U3eEoCQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_PoebhOh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8U3eEoCQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_wDy4PlGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_md5ryDRJ, 0, m, &cVar_md5ryDRJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_o10f8HLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nojmJm50_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1nrXHmIU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fPJpH3tM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b0SA1vBO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tUxGXQ3L_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_tUxGXQ3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BGo7UYB2, 0, m, &cVar_BGo7UYB2_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_b0SA1vBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_73X9jOcT, 1, m, &cIf_73X9jOcT_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_nojmJm50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mCq29jIK, 1, m, &cIf_mCq29jIK_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_1nrXHmIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_md5ryDRJ, 0, m, &cVar_md5ryDRJ_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_6rcO3Py6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_MaFwKMiX_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_66WPHcEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7nPDrt3r_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_JGs9PhHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nPno2M9A_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_GUxEctux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BGo7UYB2, 0, m, &cVar_BGo7UYB2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_teR9G24E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HPioXMjM_sendMessage(_c, 0, m);
  cMsg_6BtkA9F2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_58JUBOO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wq4w40A0_sendMessage(_c, 0, m);
  cMsg_ekazCZHX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_TqwdOk2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XOFMq4p2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_AFRxuXSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KAF29Qr7, 0, m, &cVar_KAF29Qr7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RrEaoiJY, 0, m, &cVar_RrEaoiJY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OAJODOgc, 0, m, &cVar_OAJODOgc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2nvT5Kyf, 0, m, &cVar_2nvT5Kyf_sendMessage);
  cMsg_IhnBioiE_sendMessage(_c, 0, m);
  cMsg_vY6LaGVq_sendMessage(_c, 0, m);
  cMsg_FuwOPb3S_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_niTCNzyY, 0, m, &cVar_niTCNzyY_sendMessage);
  cMsg_4k0VD03R_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZOq8ysey, 0, m, &cVar_ZOq8ysey_sendMessage);
  cMsg_bk9qPHq8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_I4u8wuc7, 0, m, &cVar_I4u8wuc7_sendMessage);
  cMsg_bXvXfyIV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TY0bgjHB, 0, m, &cVar_TY0bgjHB_sendMessage);
  cMsg_Q90x0BUc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vXMgrwFK, 0, m, &cVar_vXMgrwFK_sendMessage);
  cMsg_fWeiCsWs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RmdEMNcW, 0, m, &cVar_RmdEMNcW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7GAr14Gf, 0, m, &cVar_7GAr14Gf_sendMessage);
  cMsg_gQJke5OB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7P9qRyOd, 0, m, &cVar_7P9qRyOd_sendMessage);
  cMsg_B1tJ4dUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_S5Mmlahf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_q23LFib1_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_gzUjRh0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IEiPqI8y, 0, m, &cVar_IEiPqI8y_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_2jlfti2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BbLqVxOR, 0, m, &cVar_BbLqVxOR_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_MNXyp7AG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6obXUsK6_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_FwRqGSxT, VOf(Bf0));
    __hv_line_f(&sLine_S0T6Umkf, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_LRDwZy5p, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_zahyPjrI, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_GMikc1lG, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_1OXkZ7vq, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_wsUlEnhj, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_zeNKv9yM, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_L0ZJkojx, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_wO6E4ILF, VOf(Bf0));
    __hv_line_f(&sLine_IvKBfGhx, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_PgXFOL4E, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_yJiVPpnz, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_KsgFhS3w, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_WRrdGEAP, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_AutGd6Wx, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_USL6nXye, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_1HcDueMl, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_8DJ7xIgU, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_XozThD2d, VIf(Bf0));
    __hv_varread_f(&sVarf_E56eBJNu, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_lB6MzHd5, VIf(Bf0));
    __hv_varread_f(&sVarf_2VclhD00, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_JxOH7E3J, VOf(Bf1));
    __hv_rpole_f(&sRPole_fT1lqf9W, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_P42bGxhh, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_RwnmUzOs, VOf(Bf1));
    __hv_rpole_f(&sRPole_cEVvvuSt, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_OGybeCDF, VOf(Bf0));
    __hv_rpole_f(&sRPole_ooxLRzUO, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_MGrl1H7y, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_VPlDQFMr, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_vmbl2UT9, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_OqbZbbFT, VOf(Bf0));
    __hv_varread_f(&sVarf_pIIm8xnA, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_6s7faMvk, VOf(Bf4));
    __hv_rpole_f(&sRPole_hhIReGre, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_bWEVxBqB, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_IrePXWeE, VOf(Bf4));
    __hv_rpole_f(&sRPole_I41MgiXu, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mAmUBUBM, VOf(Bf6));
    __hv_rpole_f(&sRPole_maAG4yNd, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_yFm0xmC2, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_9hp6f2wz, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_VdA2SG1c, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_8dJH45m1, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_8DJ7xIgU, VIf(Bf6));
    __hv_line_f(&sLine_STjB5l4b, VOf(Bf6));
    __hv_line_f(&sLine_ya8NliPL, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_E56eBJNu, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
