/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvSignalDel1.h"
#include "HvSignalLine.h"
#include "HvSignalTabread.h"
#include "HvMath.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvControlUnop.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_WX31vYo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y7P55ijh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zabvi97j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1gtpbXDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tCarGOd4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_x8WhEC3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KAF29Qr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nT6rzNez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8U3eEoCQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_m5NnKGeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RrEaoiJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MSfw3YUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TbjWeCoy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SkIjSHl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OAJODOgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_P85eNyAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XOFMq4p2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QSmgLqZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HnupXVCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MKJ6GOgD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pm88IFLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2DE3JjXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wG9mMrVP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dpQS6EgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z3a2ABF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uZ3eIR1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ATpvelG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ok9HP6av_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I3Bb2AFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q23LFib1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_34eJrTf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z4WAvaz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PrwS66mO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YoopoVju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xXyMjoua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RY0Rs3vL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ysoHjFx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hFblprgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6MxgAuZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zoi1oxpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_y863iX0k_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cBvUM7VV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2nvT5Kyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Lo74DwcA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IhnBioiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Z1vMzHp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_l5cezxbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Hub4JQVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dcERrpIY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_n2d3tmh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_nwHTRhln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2hKEsoQ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wmx7maFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UwwUbawF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KEesF7aI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KVVWitLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DPp9IQeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vY6LaGVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_D1oMU9mR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_j1oqibuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5TL2hQlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iZabvrrF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ottVteYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_RHjd0M2A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a0bTUCQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bHPDmVqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y0N0GybQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2pTk0FRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZTIJ5hOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LzcscTBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_niTCNzyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FuwOPb3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_L0PFIeBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YAuUK2pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sY7UnFWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5yYVIrv5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QFjog0wk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vKw7b1H2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_APDpSjHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZOq8ysey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4k0VD03R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iWcsspYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uj450PIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RYPXB9Ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bnKTNmXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s2JumJOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X7s9dou6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hqg4l1jX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XFRGtjCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XiCkoyO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I4u8wuc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bk9qPHq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MvnSb5ol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5K60Mm8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_faMnTjap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wa8JQ1qU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WQcCSZbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kwoQ8NFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qjv10sSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KzzX8s6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gyiAR3Wr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gQJke5OB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VNaQpTY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7GAr14Gf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qSLsKRIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZxf9LXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9fd6i2tm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eXmGd4ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B1tJ4dUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jwDnYih4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7P9qRyOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3iNAfodq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xL8xy8qk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0S4dLoec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PKsbleTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TY0bgjHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bXvXfyIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rklB4u8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MfD87KbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nFZgtMr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6I0tX7Us_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nvYQxtDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NlNQCOqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PNwvrfg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vXMgrwFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q90x0BUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KMFIO4Nr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GJjo3J3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p3aRyezp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4enO9lcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y8pKNEr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ul5jR7dJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HxEJVZZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rZAl19RJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gU1sPE2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RmdEMNcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWeiCsWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7BcKvt7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K0xt9rTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OvqhvC74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o4ZQeZ8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KsKhDgQM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K9yvyUzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QMERh3nB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cdjBoASc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uGDqb4LI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xAARg9te_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1UmTjpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rf0XRJQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JbsjT7Oc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XCLADf5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7xr0b6TY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwY3OaXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_chN460kb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HPioXMjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6BtkA9F2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wq4w40A0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ekazCZHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IEiPqI8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7M883hUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mCq29jIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_73X9jOcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BGo7UYB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_md5ryDRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PcG2a52K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Njs5dThZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_liAFsYlr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xj35LjUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_kqDhsaiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mtb29ET8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zPJzssOZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NOCfdngP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xFZAKV9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KdW71ze5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V0cJzKH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PDfKe4k7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BbLqVxOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6obXUsK6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_WCMiTE25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_42P89PWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_esQ79qfm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4L0F0kHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ccbUlxib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BeV6cUvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X5eXzrJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7Q2DkZni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oTjmBgKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h1qjYZfV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7BrrYLg5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EY5wqcnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1oGxzsxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sNmyFX8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SA4omiXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PG9pa1W1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tf2IIU9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HryMJQ7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kcZuPdLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EGDAiv7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6zLXdOXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lej5JYIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1nDGtkEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eyD5KbLd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_72rtkaJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yNlPObIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k9Lq6nz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4kZk34en_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SjgZNOMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6VTNRJDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uytH5GzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jR3dyh5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ksw6wvlO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GuNonHi6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MaFwKMiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7nPDrt3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nPno2M9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZArTCX7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PoebhOh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wDy4PlGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o10f8HLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fPJpH3tM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tUxGXQ3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b0SA1vBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nojmJm50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1nrXHmIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6rcO3Py6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_66WPHcEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JGs9PhHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GUxEctux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_teR9G24E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_58JUBOO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TqwdOk2p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AFRxuXSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_S5Mmlahf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gzUjRh0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2jlfti2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MNXyp7AG_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_FwRqGSxT;
  SignalLine sLine_S0T6Umkf;
  SignalTabhead sTabhead_LRDwZy5p;
  SignalTabread sTabread_wsUlEnhj;
  SignalTabread sTabread_zeNKv9yM;
  SignalLine sLine_L0ZJkojx;
  SignalLine sLine_wO6E4ILF;
  SignalLine sLine_IvKBfGhx;
  SignalTabhead sTabhead_PgXFOL4E;
  SignalTabread sTabread_AutGd6Wx;
  SignalTabread sTabread_USL6nXye;
  SignalLine sLine_1HcDueMl;
  SignalTabwrite sTabwrite_XozThD2d;
  SignalTabwrite sTabwrite_lB6MzHd5;
  SignalRPole sRPole_fT1lqf9W;
  SignalRPole sRPole_cEVvvuSt;
  SignalRPole sRPole_ooxLRzUO;
  SignalDel1 sDel1_MGrl1H7y;
  SignalLine sLine_vmbl2UT9;
  SignalLine sLine_OqbZbbFT;
  SignalRPole sRPole_hhIReGre;
  SignalRPole sRPole_I41MgiXu;
  SignalRPole sRPole_maAG4yNd;
  SignalDel1 sDel1_yFm0xmC2;
  SignalLine sLine_VdA2SG1c;
  SignalLine sLine_8dJH45m1;
  SignalLine sLine_STjB5l4b;
  SignalLine sLine_ya8NliPL;
  ControlVar cVar_WX31vYo6;
  ControlVar cVar_y7P55ijh;
  ControlVar cVar_Zabvi97j;
  ControlVar cVar_1gtpbXDe;
  ControlSlice cSlice_x8WhEC3k;
  ControlVar cVar_KAF29Qr7;
  ControlSlice cSlice_m5NnKGeE;
  ControlVar cVar_RrEaoiJY;
  ControlSlice cSlice_SkIjSHl5;
  ControlVar cVar_OAJODOgc;
  ControlBinop cBinop_XOFMq4p2;
  ControlBinop cBinop_QSmgLqZe;
  ControlBinop cBinop_pm88IFLW;
  ControlBinop cBinop_2DE3JjXZ;
  ControlBinop cBinop_Z3a2ABF7;
  ControlBinop cBinop_5ATpvelG;
  ControlBinop cBinop_ok9HP6av;
  ControlBinop cBinop_I3Bb2AFd;
  ControlBinop cBinop_q23LFib1;
  ControlBinop cBinop_34eJrTf5;
  ControlBinop cBinop_Z4WAvaz2;
  ControlBinop cBinop_PrwS66mO;
  ControlBinop cBinop_RY0Rs3vL;
  ControlBinop cBinop_hFblprgy;
  ControlBinop cBinop_6MxgAuZe;
  ControlBinop cBinop_zoi1oxpg;
  ControlSlice cSlice_cBvUM7VV;
  ControlVar cVar_2nvT5Kyf;
  ControlDelay cDelay_l5cezxbt;
  ControlDelay cDelay_Hub4JQVd;
  ControlBinop cBinop_n2d3tmh1;
  HvTable hTable_nwHTRhln;
  ControlBinop cBinop_Wmx7maFY;
  ControlDelay cDelay_j1oqibuo;
  ControlDelay cDelay_5TL2hQlg;
  ControlBinop cBinop_ottVteYe;
  HvTable hTable_RHjd0M2A;
  ControlBinop cBinop_bHPDmVqw;
  ControlVar cVar_niTCNzyY;
  ControlBinop cBinop_YAuUK2pf;
  ControlBinop cBinop_sY7UnFWr;
  SignalVarf sVarf_JxOH7E3J;
  ControlBinop cBinop_QFjog0wk;
  ControlBinop cBinop_vKw7b1H2;
  ControlBinop cBinop_APDpSjHB;
  SignalVarf sVarf_2VclhD00;
  ControlVar cVar_ZOq8ysey;
  ControlBinop cBinop_uj450PIq;
  ControlBinop cBinop_RYPXB9Ny;
  SignalVarf sVarf_RwnmUzOs;
  ControlBinop cBinop_s2JumJOz;
  ControlBinop cBinop_X7s9dou6;
  ControlBinop cBinop_Hqg4l1jX;
  SignalVarf sVarf_P42bGxhh;
  ControlBinop cBinop_XFRGtjCr;
  ControlBinop cBinop_XiCkoyO4;
  SignalVarf sVarf_OGybeCDF;
  ControlVar cVar_I4u8wuc7;
  ControlBinop cBinop_5K60Mm8z;
  ControlBinop cBinop_faMnTjap;
  ControlBinop cBinop_WQcCSZbe;
  ControlBinop cBinop_kwoQ8NFm;
  ControlBinop cBinop_Qjv10sSk;
  ControlBinop cBinop_KzzX8s6l;
  ControlBinop cBinop_gyiAR3Wr;
  SignalVarf sVarf_VPlDQFMr;
  ControlVar cVar_7GAr14Gf;
  ControlBinop cBinop_qZxf9LXZ;
  ControlBinop cBinop_eXmGd4ic;
  SignalVarf sVarf_1OXkZ7vq;
  SignalVarf sVarf_zahyPjrI;
  SignalVarf sVarf_GMikc1lG;
  ControlVar cVar_7P9qRyOd;
  ControlBinop cBinop_xL8xy8qk;
  ControlBinop cBinop_PKsbleTe;
  SignalVarf sVarf_WRrdGEAP;
  SignalVarf sVarf_yJiVPpnz;
  SignalVarf sVarf_KsgFhS3w;
  ControlVar cVar_TY0bgjHB;
  ControlBinop cBinop_MfD87KbT;
  ControlBinop cBinop_nFZgtMr5;
  SignalVarf sVarf_6s7faMvk;
  ControlBinop cBinop_nvYQxtDM;
  ControlBinop cBinop_NlNQCOqk;
  ControlBinop cBinop_PNwvrfg3;
  SignalVarf sVarf_pIIm8xnA;
  ControlVar cVar_vXMgrwFK;
  ControlBinop cBinop_GJjo3J3i;
  ControlBinop cBinop_p3aRyezp;
  SignalVarf sVarf_IrePXWeE;
  ControlBinop cBinop_Y8pKNEr1;
  ControlBinop cBinop_ul5jR7dJ;
  ControlBinop cBinop_HxEJVZZf;
  SignalVarf sVarf_bWEVxBqB;
  ControlBinop cBinop_rZAl19RJ;
  ControlBinop cBinop_gU1sPE2Y;
  SignalVarf sVarf_mAmUBUBM;
  ControlVar cVar_RmdEMNcW;
  ControlBinop cBinop_K0xt9rTO;
  ControlBinop cBinop_OvqhvC74;
  ControlBinop cBinop_KsKhDgQM;
  ControlBinop cBinop_K9yvyUzH;
  ControlBinop cBinop_QMERh3nB;
  ControlBinop cBinop_cdjBoASc;
  ControlBinop cBinop_uGDqb4LI;
  SignalVarf sVarf_9hp6f2wz;
  SignalVarf sVarf_8DJ7xIgU;
  SignalVarf sVarf_E56eBJNu;
  ControlVar cVar_IEiPqI8y;
  ControlBinop cBinop_7M883hUx;
  ControlIf cIf_mCq29jIK;
  ControlIf cIf_73X9jOcT;
  ControlVar cVar_BGo7UYB2;
  ControlVar cVar_md5ryDRJ;
  ControlVar cVar_PcG2a52K;
  ControlVar cVar_Njs5dThZ;
  ControlSlice cSlice_xj35LjUX;
  ControlSlice cSlice_kqDhsaiz;
  ControlVar cVar_mtb29ET8;
  ControlIf cIf_zPJzssOZ;
  ControlBinop cBinop_KdW71ze5;
  ControlVar cVar_BbLqVxOR;
  ControlBinop cBinop_sNmyFX8U;
  ControlBinop cBinop_SA4omiXZ;
  ControlBinop cBinop_MaFwKMiX;
  ControlBinop cBinop_7nPDrt3r;
  ControlBinop cBinop_nPno2M9A;
  ControlBinop cBinop_wDy4PlGa;
  ControlBinop cBinop_o10f8HLU;
  ControlBinop cBinop_fPJpH3tM;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
